class ObjectData:
    def __init__(self, objectData):
        self.__ID_object = objectData['ID_object']
        self.__title = objectData['title']
        self.__mode = objectData['mode']
        self.__type = objectData['type']

        if 'data' in objectData:
            if len(objectData['data']) > 0:
                self.__data = objectData['data']

        if 'Reader' in objectData:
            if len(objectData['Reader']) > 0:
                self.__reader = objectData['Reader'][0]

        if 'Process' in objectData:
            if len(objectData['Process']) > 0:
                self.__process = objectData['Process']

    def getIdObject(self):
        return self.__ID_object

    def getTitle(self):
        return self.__title

    def getMode(self):
        return self.__mode

    def getType(self):
        return self.__type

    def getData(self):
        return self.__data

    def getReader(self):
        return self.__reader

    def getProcess(self):
        return self.__process



import json

import requests

from sdsRayanArvin.Cache import Cache
from sdsRayanArvin.Token import Token


class Request(Token, Cache):

    def __init__(self, URL):
        super().__init__()
        Cache.__init__(self)
        Token.__init__(self)
        self.Url = URL

    def sendWithToken(self, method, url, body={}):
        res = requests.request(method, self.Url + url, data=body, headers={"Authorization": "bearer " + self.getToken()})
        return json.loads(res.text)

    def sendWithOutToken(self, method, url, body={}):
        res = requests.request(method, self.Url + url, data=body)
        return json.loads(res.text)



from sdsRayanArvin.Dataset.ObjectData import ObjectData
from sdsRayanArvin.Request import Request
from sdsRayanArvin.Repository import Repository


class Object(Repository):
    def __init__(self, requestClass: Request):
        self.Request = requestClass

    def ObjectByIdOrg(self) -> ObjectData:
        """
        get object data
        :return: :class:`Object <Object>` object
        """

        res = self.Request.sendWithToken('GET', 'object')
        objData = []
        for obj in res['Object']:
            objData.append(ObjectData(obj))

        return objData



from sdsRayanArvin.Dataset.AuxStationData import AuxStationData
from sdsRayanArvin.Repository import Repository


class AuxStation(Repository):
    def AuxAll(self):
        res = self.Request.sendWithToken('GET', 'aux_all')
        auxs = []
        for aux in res['Aux']:
            auxs.append(AuxStationData(aux).aux)
        return auxs

    def AuxOnID(self, ID_AUX_station):
        # if self.Request.getCache('aux/' + ID_AUX_station) is not None:
        #     return self.Request.getCache('aux/' + ID_AUX_station)
        # else:
        #     res = self.Request.sendWithToken('GET', 'aux/' + ID_AUX_station)
        #     data = AuxStationData(res['Aux']).aux
        #     self.Request.setCache('aux/' + ID_AUX_station, data)
        #     return data
        res = self.Request.sendWithToken('GET', 'aux/' + ID_AUX_station)
        return AuxStationData(res['Aux']).aux